CSKIP_R

Struct CSKIP_R 

pub struct CSKIP_R(/* private fields */);
Field CSKIP reader - Skip rules on Carry if needed. This operation will be skipped based on Carry value (from previous operation) if not 0:

Implementations

Source

impl CSKIP_R

pub fn variant(&self) -> CSKIP_A

Get enumerated values variant

pub fn is_no_skip(&self) -> bool

Checks if the value of the field is NO_SKIP

pub fn is_skip_if_1(&self) -> bool

Checks if the value of the field is SKIP_IF_1

pub fn is_skip_if_0(&self) -> bool

Checks if the value of the field is SKIP_IF_0

pub fn is_set_and_skip(&self) -> bool

Checks if the value of the field is SET_AND_SKIP

Methods from Deref<Target = FieldReader<u8, CSKIP_A>>

pub fn bits(&self) -> U

Reads raw bits from field.