R

Struct R 

pub struct R(/* private fields */);
Register CTRL1 reader

Implementations

Source

impl R

pub fn iter(&self) -> ITER_R

Bits 0:7 - Iteration counter. Is number_cycles - 1. write 0 means Does one cycle - does not iterate.

pub fn mode(&self) -> MODE_R

Bits 8:15 - Operation mode to perform. write 0 means Accelerator is inactive. write others means accelerator is active.

pub fn resbpair(&self) -> RESBPAIR_R

Bit 16 - Which bank-pair the offset RESOFF is within. This must be 0 if only 2-up. Ideally this is not the same bank as ABBPAIR (when 4-up supported)

pub fn resoff(&self) -> RESOFF_R

Bits 18:28 - Word or DWord Offset of result. Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the AB and CD values

pub fn cskip(&self) -> CSKIP_R

Bits 30:31 - Skip rules on Carry if needed. This operation will be skipped based on Carry value (from previous operation) if not 0:

Methods from Deref<Target = R<CTRL1_SPEC>>

pub fn bits(&self) -> REG::Ux

Reads raw bits from register.