DATA_W

Struct DATA_W 

pub struct DATA_W<'a> { /* private fields */ }
Field DATA writer - Write next word in little-endian form. The hash requires big endian word data, but this block swaps the bytes automatically. That is, SHA assumes the data coming in is treated as bytes (e.g. “abcd”) and since the ARM core will treat “abcd” as a word as 0x64636261, the block will swap the word to restore into big endian.

Implementations

Source

impl<'a> DATA_W<'a>

pub unsafe fn bits(self, value: u32) -> &'a mut W

Writes raw bits to the field