COUNT_W

Struct COUNT_W 

pub struct COUNT_W<'a> { /* private fields */ }
Field COUNT writer - Number of 512-bit (128-bit if AES, except 1st block which may include key and IV) blocks to copy starting at MEMADDR. This register will decrement after each block is copied, ending in 0. For Hash, the DIGEST interrupt will occur when it reaches 0. Fro AES, the DIGEST/OUTDATA interrupt will occur on ever block. If a bus error occurs, it will stop with this field set to the block that failed. 0:Done - nothing to process. 1 to 2K: Number of 512-bit (or 128bit) blocks to hash.

Implementations

Source

impl<'a> COUNT_W<'a>

pub unsafe fn bits(self, value: u16) -> &'a mut W

Writes raw bits to the field