RegisterBlock

Struct RegisterBlock 

#[repr(C)]
pub struct RegisterBlock {
Show 19 fields pub cfg: Reg<CFG_SPEC>, pub stat: Reg<STAT_SPEC>, pub intenset: Reg<INTENSET_SPEC>, pub intenclr: Reg<INTENCLR_SPEC>, pub timeout: Reg<TIMEOUT_SPEC>, pub clkdiv: Reg<CLKDIV_SPEC>, pub intstat: Reg<INTSTAT_SPEC>, pub mstctl: Reg<MSTCTL_SPEC>, pub msttime: Reg<MSTTIME_SPEC>, pub mstdat: Reg<MSTDAT_SPEC>, pub slvctl: Reg<SLVCTL_SPEC>, pub slvdat: Reg<SLVDAT_SPEC>, pub slvadr0: Reg<SLVADR0_SPEC>, pub slvadr1: Reg<SLVADR1_SPEC>, pub slvadr2: Reg<SLVADR2_SPEC>, pub slvadr3: Reg<SLVADR3_SPEC>, pub slvqual0: Reg<SLVQUAL0_SPEC>, pub monrxdat: Reg<MONRXDAT_SPEC>, pub id: Reg<ID_SPEC>, /* private fields */
}
Register block

Fields

cfg: Reg<CFG_SPEC>

0x800 - Configuration for shared functions.

stat: Reg<STAT_SPEC>

0x804 - Status register for Master, Slave, and Monitor functions.

intenset: Reg<INTENSET_SPEC>

0x808 - Interrupt Enable Set and read register.

intenclr: Reg<INTENCLR_SPEC>

0x80c - Interrupt Enable Clear register.

timeout: Reg<TIMEOUT_SPEC>

0x810 - Time-out value register.

clkdiv: Reg<CLKDIV_SPEC>

0x814 - Clock pre-divider for the entire I2C interface. This determines what time increments are used for the MSTTIME register, and controls some timing of the Slave function.

intstat: Reg<INTSTAT_SPEC>

0x818 - Interrupt Status register for Master, Slave, and Monitor functions.

mstctl: Reg<MSTCTL_SPEC>

0x820 - Master control register.

msttime: Reg<MSTTIME_SPEC>

0x824 - Master timing configuration.

mstdat: Reg<MSTDAT_SPEC>

0x828 - Combined Master receiver and transmitter data register.

slvctl: Reg<SLVCTL_SPEC>

0x840 - Slave control register.

slvdat: Reg<SLVDAT_SPEC>

0x844 - Combined Slave receiver and transmitter data register.

slvadr0: Reg<SLVADR0_SPEC>

0x848 - Slave address register.

slvadr1: Reg<SLVADR1_SPEC>

0x84c - Slave address register.

slvadr2: Reg<SLVADR2_SPEC>

0x850 - Slave address register.

slvadr3: Reg<SLVADR3_SPEC>

0x854 - Slave address register.

slvqual0: Reg<SLVQUAL0_SPEC>

0x858 - Slave Qualification for address 0.

monrxdat: Reg<MONRXDAT_SPEC>

0x880 - Monitor receiver data register.

id: Reg<ID_SPEC>

0xffc - Peripheral identification register.