#[repr(C)]pub struct RegisterBlock {
pub channel: [CHANNEL; 4],
pub modcfg: Reg<MODCFG_SPEC>,
pub idle_ch: Reg<IDLE_CH_SPEC>,
pub irq_flag: Reg<IRQ_FLAG_SPEC>,
/* private fields */
}Expand description
Register block
Fields
channel: [CHANNEL; 4]0x00..0x40 - no description available
modcfg: Reg<MODCFG_SPEC>0xf0 - Module Configuration register. This register provides information about this particular MRT instance, and allows choosing an overall mode for the idle channel feature.
idle_ch: Reg<IDLE_CH_SPEC>0xf4 - Idle channel register. This register returns the number of the first idle channel.
irq_flag: Reg<IRQ_FLAG_SPEC>0xf8 - Global interrupt flag register