pub struct R(/* private fields */);Expand description
Register OSEVENT_CTRL reader
Implementations
Sourceimpl R
impl R
Sourcepub fn ostimer_intrflag(&self) -> OSTIMER_INTRFLAG_R
pub fn ostimer_intrflag(&self) -> OSTIMER_INTRFLAG_R
Bit 0 - This bit is set when a match occurs between the central 42-bits EVTIMER and the value programmed in the match-register pair. This bit is cleared by writing a ‘1’. Writes to clear this bit are asynchronous. It should be done before a new match value is written into the MATCH_L/H registers.
Sourcepub fn ostimer_intena(&self) -> OSTIMER_INTENA_R
pub fn ostimer_intena(&self) -> OSTIMER_INTENA_R
Bit 1 - When this bit is ‘1’ an interrupt/wakeup request to the domain processor will be asserted when the OSTIMER_INTR flag is set. When this bit is ‘0’, interrupt/wakeup requests due to the OSTIMER_INTR flag are blocked.
Sourcepub fn match_wr_rdy(&self) -> MATCH_WR_RDY_R
pub fn match_wr_rdy(&self) -> MATCH_WR_RDY_R
Bit 2 - This bit will be low when it is safe to write to reload the Match Registers. In typical applications it should not be necessary to test this bit. [1]
Methods from Deref<Target = R<OSEVENT_CTRL_SPEC>>