pub enum RTC_EN_A {
DISABLE = 0,
ENABLE = 1,
}Expand description
RTC enable.
Value on reset: 0
Variants
DISABLE = 0
0: Disable. The RTC 1 Hz and 1 kHz clocks are shut down and the RTC operation is disabled. This bit should be 0 when writing to load a value in the RTC counter register.
ENABLE = 1
1: Enable. The 1 Hz RTC clock is running and RTC operation is enabled. This bit must be set to initiate operation of the RTC. The first clock to the RTC counter occurs 1 s after this bit is set. To also enable the high-resolution, 1 kHz clock, set bit 6 in this register.