pub struct RTC_OSC_PD_R(/* private fields */);Expand description
Field RTC_OSC_PD reader - RTC oscillator power-down control.
Implementations
Sourceimpl RTC_OSC_PD_R
impl RTC_OSC_PD_R
Sourcepub fn variant(&self) -> RTC_OSC_PD_A
pub fn variant(&self) -> RTC_OSC_PD_A
Get enumerated values variant
Sourcepub fn is_power_up(&self) -> bool
pub fn is_power_up(&self) -> bool
Checks if the value of the field is POWER_UP
Sourcepub fn is_powered_down(&self) -> bool
pub fn is_powered_down(&self) -> bool
Checks if the value of the field is POWERED_DOWN
Methods from Deref<Target = FieldReader<bool, RTC_OSC_PD_A>>