SWRESET_W

Struct SWRESET_W 

pub struct SWRESET_W<'a> { /* private fields */ }
Field SWRESET writer - Software reset control

Implementations

Source

impl<'a> SWRESET_W<'a>

pub fn variant(self, variant: SWRESET_A) -> &'a mut W

Writes variant to the field

pub fn not_in_reset(self) -> &'a mut W

Not in reset. The RTC is not held in reset. This bit must be cleared prior to configuring or initiating any operation of the RTC.

pub fn in_reset(self) -> &'a mut W

In reset. The RTC is held in reset. All register bits within the RTC will be forced to their reset value except the OFD bit. This bit must be cleared before writing to any register in the RTC - including writes to set any of the other bits within this register. Do not attempt to write to any bits of this register at the same time that the reset bit is being cleared.

pub fn set_bit(self) -> &'a mut W

Sets the field bit

pub fn clear_bit(self) -> &'a mut W

Clears the field bit

pub fn bit(self, value: bool) -> &'a mut W

Writes raw bits to the field