pub struct R(/* private fields */);Expand description
Register CAPCTRL2 reader
Implementations
Sourceimpl R
impl R
Sourcepub fn capconn_l(&self) -> CAPCONN_L_R
pub fn capconn_l(&self) -> CAPCONN_L_R
Bits 0:15 - If bit m is one, event m causes the CAPn_L (UNIFY = 0) or the CAPn (UNIFY = 1) register to be loaded (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of match/captures in this SCT.
Sourcepub fn capconn_h(&self) -> CAPCONN_H_R
pub fn capconn_h(&self) -> CAPCONN_H_R
Bits 16:31 - If bit m is one, event m causes the CAPn_H (UNIFY = 0) register to be loaded (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of match/captures in this SCT.
Methods from Deref<Target = R<CAPCTRL2_SPEC>>