pub struct PBYTE_R(/* private fields */);Expand description
Field PBYTE reader - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin’s output bit. One register for each port pin. Supported pins depends on the specific device and package.
Methods from Deref<Target = FieldReader<bool, bool>>