INT_SOURCE_A

Enum INT_SOURCE_A 

pub enum INT_SOURCE_A {
    FILTER_INT = 0,
    RAW_INT = 1,
}
Select which Analog comparator output (filtered our un-filtered) is used for interrupt detection.

Value on reset: 0

Variants



FILTER_INT = 0

0: Select Analog Comparator filtered output as input for interrupt detection.



RAW_INT = 1

1: Select Analog Comparator raw output (unfiltered) as input for interrupt detection. Must be used when Analog comparator is used as wake up source in Power down mode.