pub struct INT_ENABLE_R(/* private fields */);Expand description
Field INT_ENABLE reader - Analog Comparator interrupt enable control:.
Implementations
Sourceimpl INT_ENABLE_R
impl INT_ENABLE_R
Sourcepub fn variant(&self) -> INT_ENABLE_A
pub fn variant(&self) -> INT_ENABLE_A
Get enumerated values variant
Sourcepub fn is_int_disable(&self) -> bool
pub fn is_int_disable(&self) -> bool
Checks if the value of the field is INT_DISABLE
Sourcepub fn is_int_enable(&self) -> bool
pub fn is_int_enable(&self) -> bool
Checks if the value of the field is INT_ENABLE
Methods from Deref<Target = FieldReader<bool, INT_ENABLE_A>>