pub struct INT_SOURCE_R(/* private fields */);Expand description
Field INT_SOURCE reader - Select which Analog comparator output (filtered our un-filtered) is used for interrupt detection.
Implementations
Sourceimpl INT_SOURCE_R
impl INT_SOURCE_R
Sourcepub fn variant(&self) -> INT_SOURCE_A
pub fn variant(&self) -> INT_SOURCE_A
Get enumerated values variant
Sourcepub fn is_filter_int(&self) -> bool
pub fn is_filter_int(&self) -> bool
Checks if the value of the field is FILTER_INT
Sourcepub fn is_raw_int(&self) -> bool
pub fn is_raw_int(&self) -> bool
Checks if the value of the field is RAW_INT
Methods from Deref<Target = FieldReader<bool, INT_SOURCE_A>>