INT_SOURCE_W

Struct INT_SOURCE_W 

pub struct INT_SOURCE_W<'a> { /* private fields */ }
Field INT_SOURCE writer - Select which Analog comparator output (filtered our un-filtered) is used for interrupt detection.

Implementations

Source

impl<'a> INT_SOURCE_W<'a>

pub fn variant(self, variant: INT_SOURCE_A) -> &'a mut W

Writes variant to the field

pub fn filter_int(self) -> &'a mut W

Select Analog Comparator filtered output as input for interrupt detection.

pub fn raw_int(self) -> &'a mut W

Select Analog Comparator raw output (unfiltered) as input for interrupt detection. Must be used when Analog comparator is used as wake up source in Power down mode.

pub fn set_bit(self) -> &'a mut W

Sets the field bit

pub fn clear_bit(self) -> &'a mut W

Clears the field bit

pub fn bit(self, value: bool) -> &'a mut W

Writes raw bits to the field