pub struct R(/* private fields */);Expand description
Register NMISRC reader
Implementations
Sourceimpl R
impl R
Sourcepub fn irqcpu0(&self) -> IRQCPU0_R
pub fn irqcpu0(&self) -> IRQCPU0_R
Bits 0:5 - The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for the CPU0, if enabled by NMIENCPU0.
Sourcepub fn irqcpu1(&self) -> IRQCPU1_R
pub fn irqcpu1(&self) -> IRQCPU1_R
Bits 8:13 - The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for the CPU1, if enabled by NMIENCPU1.
Sourcepub fn nmiencpu1(&self) -> NMIENCPU1_R
pub fn nmiencpu1(&self) -> NMIENCPU1_R
Bit 30 - Write a 1 to this bit to enable the Non-Maskable Interrupt (NMI) source selected by IRQCPU1.
Sourcepub fn nmiencpu0(&self) -> NMIENCPU0_R
pub fn nmiencpu0(&self) -> NMIENCPU0_R
Bit 31 - Write a 1 to this bit to enable the Non-Maskable Interrupt (NMI) source selected by IRQCPU0.
Methods from Deref<Target = R<NMISRC_SPEC>>