pub struct BYPASSPLL_R(/* private fields */);Expand description
Field BYPASSPLL reader - Bypass PLL input clock is sent directly to the PLL output (default).
Implementations
Sourceimpl BYPASSPLL_R
impl BYPASSPLL_R
Sourcepub fn variant(&self) -> BYPASSPLL_A
pub fn variant(&self) -> BYPASSPLL_A
Get enumerated values variant
Sourcepub fn is_bypassed(&self) -> bool
pub fn is_bypassed(&self) -> bool
Checks if the value of the field is BYPASSED
Methods from Deref<Target = FieldReader<bool, BYPASSPLL_A>>