pub struct USB1_RAM_RST_R(/* private fields */);Expand description
Field USB1_RAM_RST reader - USB1 RAM reset control.
Implementations
Sourceimpl USB1_RAM_RST_R
impl USB1_RAM_RST_R
Sourcepub fn variant(&self) -> USB1_RAM_RST_A
pub fn variant(&self) -> USB1_RAM_RST_A
Get enumerated values variant
Sourcepub fn is_released(&self) -> bool
pub fn is_released(&self) -> bool
Checks if the value of the field is RELEASED
Sourcepub fn is_asserted(&self) -> bool
pub fn is_asserted(&self) -> bool
Checks if the value of the field is ASSERTED
Methods from Deref<Target = FieldReader<bool, USB1_RAM_RST_A>>