#[repr(u8)]pub enum DATAOUTSEL_A {
ORIG_FLEX_I2S_SIGNALS = 0,
SHARED_SET0_I2S_SIGNALS = 1,
SHARED_SET1_I2S_SIGNALS = 2,
}Expand description
Selects the source for DATA output from this Flexcomm.
Value on reset: 0
Variants
ORIG_FLEX_I2S_SIGNALS = 0
0: Selects the dedicated FCn_RXD_SDA_MOSI_DATA output from this Flexcomm.
SHARED_SET0_I2S_SIGNALS = 1
1: Output data is taken from shared signal set 0 (defined by SHAREDCTRLSET0).
SHARED_SET1_I2S_SIGNALS = 2
2: Output data is taken from shared signal set 1 (defined by SHAREDCTRLSET1).