pub struct DATAINSEL_R(/* private fields */);Expand description
Field DATAINSEL reader - Selects the source for DATA input to this Flexcomm.
Implementations
Sourceimpl DATAINSEL_R
impl DATAINSEL_R
Sourcepub fn variant(&self) -> Option<DATAINSEL_A>
pub fn variant(&self) -> Option<DATAINSEL_A>
Get enumerated values variant
Sourcepub fn is_orig_flex_i2s_signals(&self) -> bool
pub fn is_orig_flex_i2s_signals(&self) -> bool
Checks if the value of the field is ORIG_FLEX_I2S_SIGNALS
Checks if the value of the field is SHARED_SET0_I2S_SIGNALS
Checks if the value of the field is SHARED_SET1_I2S_SIGNALS
Methods from Deref<Target = FieldReader<u8, DATAINSEL_A>>