pub struct DATAOUTSEL_R(/* private fields */);Expand description
Field DATAOUTSEL reader - Selects the source for DATA output from this Flexcomm.
Implementations
Sourceimpl DATAOUTSEL_R
impl DATAOUTSEL_R
Sourcepub fn variant(&self) -> Option<DATAOUTSEL_A>
pub fn variant(&self) -> Option<DATAOUTSEL_A>
Get enumerated values variant
Sourcepub fn is_orig_flex_i2s_signals(&self) -> bool
pub fn is_orig_flex_i2s_signals(&self) -> bool
Checks if the value of the field is ORIG_FLEX_I2S_SIGNALS
Checks if the value of the field is SHARED_SET0_I2S_SIGNALS
Checks if the value of the field is SHARED_SET1_I2S_SIGNALS
Methods from Deref<Target = FieldReader<u8, DATAOUTSEL_A>>