pub struct DATAOUTSEL_W<'a> { /* private fields */ }Expand description
Field DATAOUTSEL writer - Selects the source for DATA output from this Flexcomm.
Implementations
Sourceimpl<'a> DATAOUTSEL_W<'a>
impl<'a> DATAOUTSEL_W<'a>
Sourcepub fn variant(self, variant: DATAOUTSEL_A) -> &'a mut W
pub fn variant(self, variant: DATAOUTSEL_A) -> &'a mut W
Writes variant to the field
Sourcepub fn orig_flex_i2s_signals(self) -> &'a mut W
pub fn orig_flex_i2s_signals(self) -> &'a mut W
Selects the dedicated FCn_RXD_SDA_MOSI_DATA output from this Flexcomm.
Output data is taken from shared signal set 0 (defined by SHAREDCTRLSET0).
Output data is taken from shared signal set 1 (defined by SHAREDCTRLSET1).