Module sharedctrlset

Module sharedctrlset 

Selects sources and data combinations for shared signal set index.

Structs

FC0DATAOUTEN_R
Field FC0DATAOUTEN reader - Controls FC0 contribution to SHAREDDATAOUT for this shared set.
FC0DATAOUTEN_W
Field FC0DATAOUTEN writer - Controls FC0 contribution to SHAREDDATAOUT for this shared set.
FC1DATAOUTEN_R
Field FC1DATAOUTEN reader - Controls FC1 contribution to SHAREDDATAOUT for this shared set.
FC1DATAOUTEN_W
Field FC1DATAOUTEN writer - Controls FC1 contribution to SHAREDDATAOUT for this shared set.
FC2DATAOUTEN_R
Field FC2DATAOUTEN reader - Controls FC2 contribution to SHAREDDATAOUT for this shared set.
FC2DATAOUTEN_W
Field FC2DATAOUTEN writer - Controls FC2 contribution to SHAREDDATAOUT for this shared set.
FC4DATAOUTEN_R
Field FC4DATAOUTEN reader - Controls FC4 contribution to SHAREDDATAOUT for this shared set.
FC4DATAOUTEN_W
Field FC4DATAOUTEN writer - Controls FC4 contribution to SHAREDDATAOUT for this shared set.
FC5DATAOUTEN_R
Field FC5DATAOUTEN reader - Controls FC5 contribution to SHAREDDATAOUT for this shared set.
FC5DATAOUTEN_W
Field FC5DATAOUTEN writer - Controls FC5 contribution to SHAREDDATAOUT for this shared set.
FC6DATAOUTEN_R
Field FC6DATAOUTEN reader - Controls FC6 contribution to SHAREDDATAOUT for this shared set.
FC6DATAOUTEN_W
Field FC6DATAOUTEN writer - Controls FC6 contribution to SHAREDDATAOUT for this shared set.
FC7DATAOUTEN_R
Field FC7DATAOUTEN reader - Controls FC7 contribution to SHAREDDATAOUT for this shared set.
FC7DATAOUTEN_W
Field FC7DATAOUTEN writer - Controls FC7 contribution to SHAREDDATAOUT for this shared set.
R
Register SHAREDCTRLSET%s reader
SHAREDCTRLSET_SPEC
Selects sources and data combinations for shared signal set index.
SHAREDDATASEL_R
Field SHAREDDATASEL reader - Selects the source for DATA input for this shared signal set.
SHAREDDATASEL_W
Field SHAREDDATASEL writer - Selects the source for DATA input for this shared signal set.
SHAREDSCKSEL_R
Field SHAREDSCKSEL reader - Selects the source for SCK of this shared signal set.
SHAREDSCKSEL_W
Field SHAREDSCKSEL writer - Selects the source for SCK of this shared signal set.
SHAREDWSSEL_R
Field SHAREDWSSEL reader - Selects the source for WS of this shared signal set.
SHAREDWSSEL_W
Field SHAREDWSSEL writer - Selects the source for WS of this shared signal set.
W
Register SHAREDCTRLSET%s writer

Enums

FC0DATAOUTEN_A
Controls FC0 contribution to SHAREDDATAOUT for this shared set.
FC1DATAOUTEN_A
Controls FC1 contribution to SHAREDDATAOUT for this shared set.
FC2DATAOUTEN_A
Controls FC2 contribution to SHAREDDATAOUT for this shared set.
FC4DATAOUTEN_A
Controls FC4 contribution to SHAREDDATAOUT for this shared set.
FC5DATAOUTEN_A
Controls FC5 contribution to SHAREDDATAOUT for this shared set.
FC6DATAOUTEN_A
Controls FC6 contribution to SHAREDDATAOUT for this shared set.
FC7DATAOUTEN_A
Controls FC7 contribution to SHAREDDATAOUT for this shared set.
SHAREDDATASEL_A
Selects the source for DATA input for this shared signal set.
SHAREDSCKSEL_A
Selects the source for SCK of this shared signal set.
SHAREDWSSEL_A
Selects the source for WS of this shared signal set.