#[repr(u8)]pub enum SHAREDDATASEL_A {
FLEXCOMM0 = 0,
FLEXCOMM1 = 1,
FLEXCOMM2 = 2,
FLEXCOMM3 = 3,
FLEXCOMM4 = 4,
FLEXCOMM5 = 5,
FLEXCOMM6 = 6,
FLEXCOMM7 = 7,
}Expand description
Selects the source for DATA input for this shared signal set.
Value on reset: 0
Variants
FLEXCOMM0 = 0
0: DATA input for this shared signal set comes from Flexcomm 0.
FLEXCOMM1 = 1
1: DATA input for this shared signal set comes from Flexcomm 1.
FLEXCOMM2 = 2
2: DATA input for this shared signal set comes from Flexcomm 2.
FLEXCOMM3 = 3
3: DATA input for this shared signal set comes from Flexcomm 3.
FLEXCOMM4 = 4
4: DATA input for this shared signal set comes from Flexcomm 4.
FLEXCOMM5 = 5
5: DATA input for this shared signal set comes from Flexcomm 5.
FLEXCOMM6 = 6
6: DATA input for this shared signal set comes from Flexcomm 6.
FLEXCOMM7 = 7
7: DATA input for this shared signal set comes from Flexcomm 7.