pub struct SHAREDDATASEL_R(/* private fields */);Expand description
Field SHAREDDATASEL reader - Selects the source for DATA input for this shared signal set.
Implementations
Sourceimpl SHAREDDATASEL_R
impl SHAREDDATASEL_R
Sourcepub fn variant(&self) -> SHAREDDATASEL_A
pub fn variant(&self) -> SHAREDDATASEL_A
Get enumerated values variant
Sourcepub fn is_flexcomm0(&self) -> bool
pub fn is_flexcomm0(&self) -> bool
Checks if the value of the field is FLEXCOMM0
Sourcepub fn is_flexcomm1(&self) -> bool
pub fn is_flexcomm1(&self) -> bool
Checks if the value of the field is FLEXCOMM1
Sourcepub fn is_flexcomm2(&self) -> bool
pub fn is_flexcomm2(&self) -> bool
Checks if the value of the field is FLEXCOMM2
Sourcepub fn is_flexcomm3(&self) -> bool
pub fn is_flexcomm3(&self) -> bool
Checks if the value of the field is FLEXCOMM3
Sourcepub fn is_flexcomm4(&self) -> bool
pub fn is_flexcomm4(&self) -> bool
Checks if the value of the field is FLEXCOMM4
Sourcepub fn is_flexcomm5(&self) -> bool
pub fn is_flexcomm5(&self) -> bool
Checks if the value of the field is FLEXCOMM5
Sourcepub fn is_flexcomm6(&self) -> bool
pub fn is_flexcomm6(&self) -> bool
Checks if the value of the field is FLEXCOMM6
Sourcepub fn is_flexcomm7(&self) -> bool
pub fn is_flexcomm7(&self) -> bool
Checks if the value of the field is FLEXCOMM7
Methods from Deref<Target = FieldReader<u8, SHAREDDATASEL_A>>