pub struct SHAREDDATASEL_W<'a> { /* private fields */ }Expand description
Field SHAREDDATASEL writer - Selects the source for DATA input for this shared signal set.
Implementations
Sourceimpl<'a> SHAREDDATASEL_W<'a>
impl<'a> SHAREDDATASEL_W<'a>
Sourcepub fn variant(self, variant: SHAREDDATASEL_A) -> &'a mut W
pub fn variant(self, variant: SHAREDDATASEL_A) -> &'a mut W
Writes variant to the field
Sourcepub fn flexcomm0(self) -> &'a mut W
pub fn flexcomm0(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 0.
Sourcepub fn flexcomm1(self) -> &'a mut W
pub fn flexcomm1(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 1.
Sourcepub fn flexcomm2(self) -> &'a mut W
pub fn flexcomm2(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 2.
Sourcepub fn flexcomm3(self) -> &'a mut W
pub fn flexcomm3(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 3.
Sourcepub fn flexcomm4(self) -> &'a mut W
pub fn flexcomm4(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 4.
Sourcepub fn flexcomm5(self) -> &'a mut W
pub fn flexcomm5(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 5.
Sourcepub fn flexcomm6(self) -> &'a mut W
pub fn flexcomm6(self) -> &'a mut W
DATA input for this shared signal set comes from Flexcomm 6.