R

Struct R 

pub struct R(/* private fields */);
Register DEVCMDSTAT reader

Implementations

Source

impl R

pub fn dev_addr(&self) -> DEV_ADDR_R

Bits 0:6 - USB device address.

pub fn dev_en(&self) -> DEV_EN_R

Bit 7 - USB device enable.

pub fn setup(&self) -> SETUP_R

Bit 8 - SETUP token received.

pub fn force_needclk(&self) -> FORCE_NEEDCLK_R

Bit 9 - Forces the NEEDCLK output to always be on:.

pub fn lpm_sup(&self) -> LPM_SUP_R

Bit 11 - LPM Supported:.

pub fn intonnak_ao(&self) -> INTONNAK_AO_R

Bit 12 - Interrupt on NAK for interrupt and bulk OUT EP:.

pub fn intonnak_ai(&self) -> INTONNAK_AI_R

Bit 13 - Interrupt on NAK for interrupt and bulk IN EP:.

pub fn intonnak_co(&self) -> INTONNAK_CO_R

Bit 14 - Interrupt on NAK for control OUT EP:.

pub fn intonnak_ci(&self) -> INTONNAK_CI_R

Bit 15 - Interrupt on NAK for control IN EP:.

pub fn dcon(&self) -> DCON_R

Bit 16 - Device status - connect.

pub fn dsus(&self) -> DSUS_R

Bit 17 - Device status - suspend.

pub fn lpm_sus(&self) -> LPM_SUS_R

Bit 19 - Device status - LPM Suspend.

pub fn lpm_rewp(&self) -> LPM_REWP_R

Bit 20 - LPM Remote Wake-up Enabled by USB host.

pub fn speed(&self) -> SPEED_R

Bits 22:23 - This field indicates the speed at which the device operates: 00b: reserved 01b: full-speed 10b: high-speed 11b: super-speed (reserved for future use).

pub fn dcon_c(&self) -> DCON_C_R

Bit 24 - Device status - connect change.

pub fn dsus_c(&self) -> DSUS_C_R

Bit 25 - Device status - suspend change.

pub fn dres_c(&self) -> DRES_C_R

Bit 26 - Device status - reset change.

pub fn vbus_debounced(&self) -> VBUS_DEBOUNCED_R

Bit 28 - This bit indicates if VBUS is detected or not.

pub fn phy_test_mode(&self) -> PHY_TEST_MODE_R

Bits 29:31 - This field is written by firmware to put the PHY into a test mode as defined by the USB2.0 specification

pub fn force_fs(&self) -> FORCE_FS_R

Bit 21 - Force USB device to operate in full-speed mode.

Methods from Deref<Target = R<DEVCMDSTAT_SPEC>>

pub fn bits(&self) -> REG::Ux

Reads raw bits from register.