W

Struct W 

pub struct W(/* private fields */);
Register DEVCMDSTAT writer

Implementations

Source

impl W

pub fn dev_addr(&mut self) -> DEV_ADDR_W<'_>

Bits 0:6 - USB device address.

pub fn dev_en(&mut self) -> DEV_EN_W<'_>

Bit 7 - USB device enable.

pub fn setup(&mut self) -> SETUP_W<'_>

Bit 8 - SETUP token received.

pub fn force_needclk(&mut self) -> FORCE_NEEDCLK_W<'_>

Bit 9 - Forces the NEEDCLK output to always be on:.

pub fn lpm_sup(&mut self) -> LPM_SUP_W<'_>

Bit 11 - LPM Supported:.

pub fn intonnak_ao(&mut self) -> INTONNAK_AO_W<'_>

Bit 12 - Interrupt on NAK for interrupt and bulk OUT EP:.

pub fn intonnak_ai(&mut self) -> INTONNAK_AI_W<'_>

Bit 13 - Interrupt on NAK for interrupt and bulk IN EP:.

pub fn intonnak_co(&mut self) -> INTONNAK_CO_W<'_>

Bit 14 - Interrupt on NAK for control OUT EP:.

pub fn intonnak_ci(&mut self) -> INTONNAK_CI_W<'_>

Bit 15 - Interrupt on NAK for control IN EP:.

pub fn dcon(&mut self) -> DCON_W<'_>

Bit 16 - Device status - connect.

pub fn dsus(&mut self) -> DSUS_W<'_>

Bit 17 - Device status - suspend.

pub fn lpm_sus(&mut self) -> LPM_SUS_W<'_>

Bit 19 - Device status - LPM Suspend.

pub fn dcon_c(&mut self) -> DCON_C_W<'_>

Bit 24 - Device status - connect change.

pub fn dsus_c(&mut self) -> DSUS_C_W<'_>

Bit 25 - Device status - suspend change.

pub fn dres_c(&mut self) -> DRES_C_W<'_>

Bit 26 - Device status - reset change.

pub fn phy_test_mode(&mut self) -> PHY_TEST_MODE_W<'_>

Bits 29:31 - This field is written by firmware to put the PHY into a test mode as defined by the USB2.0 specification

pub fn force_fs(&mut self) -> FORCE_FS_W<'_>

Bit 21 - Force USB device to operate in full-speed mode.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Methods from Deref<Target = W<DEVCMDSTAT_SPEC>>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.