pub struct DEVPLUGIN_POLARITY_R(/* private fields */);Expand description
Field DEVPLUGIN_POLARITY reader - Device plugin polarity: For device mode, if this bit is cleared to 0, then it trips the interrupt if the device is plugged in
Methods from Deref<Target = FieldReader<bool, bool>>