pub struct DEVPLUGIN_POLARITY_W<'a> { /* private fields */ }Expand description
Field DEVPLUGIN_POLARITY writer - Device plugin polarity: For device mode, if this bit is cleared to 0, then it trips the interrupt if the device is plugged in
Implementations