pub struct ENDEVPLUGINDET_R(/* private fields */);Expand description
Field ENDEVPLUGINDET reader - Enables non-standard resistive plugged-in detection This bit field controls connection of nominal 200kohm resistors to both the USB_DP and USB_DM pins as one method of detecting when a USB cable is attached in device mode
Implementations
Methods from Deref<Target = FieldReader<bool, ENDEVPLUGINDET_A>>