W

Struct W 

pub struct W(/* private fields */);
Register CTRL writer

Implementations

Source

impl W

pub fn enhostdiscondetect(&mut self) -> ENHOSTDISCONDETECT_W<'_>

Bit 1 - For host mode, enables high-speed disconnect detector

pub fn enirqhostdiscon(&mut self) -> ENIRQHOSTDISCON_W<'_>

Bit 2 - Enable IRQ for Host disconnect: Enables interrupt for detection of disconnection to Device when in high-speed host mode

pub fn hostdiscondetect_irq(&mut self) -> HOSTDISCONDETECT_IRQ_W<'_>

Bit 3 - Indicates that the device has disconnected in High-Speed mode

pub fn endevplugindet(&mut self) -> ENDEVPLUGINDET_W<'_>

Bit 4 - Enables non-standard resistive plugged-in detection This bit field controls connection of nominal 200kohm resistors to both the USB_DP and USB_DM pins as one method of detecting when a USB cable is attached in device mode

pub fn devplugin_polarity(&mut self) -> DEVPLUGIN_POLARITY_W<'_>

Bit 5 - Device plugin polarity: For device mode, if this bit is cleared to 0, then it trips the interrupt if the device is plugged in

pub fn resumeirqsticky(&mut self) -> RESUMEIRQSTICKY_W<'_>

Bit 8 - Resume IRQ: Set to 1 will make RESUME_IRQ bit a sticky bit until software clear it

pub fn enirqresumedetect(&mut self) -> ENIRQRESUMEDETECT_W<'_>

Bit 9 - Enable IRQ Resume detect: Enables interrupt for detection of a non-J state on the USB line

pub fn resume_irq(&mut self) -> RESUME_IRQ_W<'_>

Bit 10 - Resume IRQ: Indicates that the host is sending a wake-up after suspend

pub fn devplugin_irq(&mut self) -> DEVPLUGIN_IRQ_W<'_>

Bit 12 - Indicates that the device is connected

pub fn enutmilevel2(&mut self) -> ENUTMILEVEL2_W<'_>

Bit 14 - Enables UTMI+ Level 2 operation for the USB HS PHY

pub fn enutmilevel3(&mut self) -> ENUTMILEVEL3_W<'_>

Bit 15 - Enables UTMI+ Level 3 operation for the USB HS PHY

pub fn enirqwakeup(&mut self) -> ENIRQWAKEUP_W<'_>

Bit 16 - Enable wake-up IRQ: Enables interrupt for the wake-up events.

pub fn wakeup_irq(&mut self) -> WAKEUP_IRQ_W<'_>

Bit 17 - Wake-up IRQ: Indicates that there is a wak-eup event

pub fn autoresume_en(&mut self) -> AUTORESUME_EN_W<'_>

Bit 18 - Enable the auto resume feature, when set, HW will use 32KHz clock to send Resume to respond to the device remote wakeup(for host mode only)

pub fn enautoclr_clkgate(&mut self) -> ENAUTOCLR_CLKGATE_W<'_>

Bit 19 - Enables the feature to auto-clear the CLKGATE bit if there is wakeup event while USB is suspended

pub fn enautoclr_phy_pwd(&mut self) -> ENAUTOCLR_PHY_PWD_W<'_>

Bit 20 - Enables the feature to auto-clear the PWD register bits in PWD if there is wakeup event while USB is suspended

pub fn endpdmchg_wkup(&mut self) -> ENDPDMCHG_WKUP_W<'_>

Bit 21 - Enable DP DM change wake-up: Not for customer use

pub fn envbuschg_wkup(&mut self) -> ENVBUSCHG_WKUP_W<'_>

Bit 23 - Enable VBUS change wake-up: Enables the feature to wake-up USB if VBUS is toggled when USB is suspended

pub fn enautoclr_usbclkgate(&mut self) -> ENAUTOCLR_USBCLKGATE_W<'_>

Bit 25 - Enable auto-clear USB Clock gate: Enables the feature to auto-clear the USB0_CLKGATE/USB1_CLKGATE register bit in HW_DIGCTL_CTRL if there is wake-up event on USB0/USB1 while USB0/USB1 is suspended

pub fn enautoset_usbclks(&mut self) -> ENAUTOSET_USBCLKS_W<'_>

Bit 26 - Enable auto-set of USB clocks: Enables the feature to auto-clear the EN_USB_CLKS register bits in HW_CLKCTRL_PLL1CTRL0/HW_CLKCTRL_P LL1CTRL1 if there is wake-up event on USB0/USB1 while USB0/USB1 is suspended

pub fn host_force_ls_se0(&mut self) -> HOST_FORCE_LS_SE0_W<'_>

Bit 28 - Forces the next FS packet that is transmitted to have a EOP with low-speed timing

pub fn utmi_suspendm(&mut self) -> UTMI_SUSPENDM_W<'_>

Bit 29 - Used by the PHY to indicate a powered-down state

pub fn clkgate(&mut self) -> CLKGATE_W<'_>

Bit 30 - Gate UTMI Clocks

pub fn sftrst(&mut self) -> SFTRST_W<'_>

Bit 31 - Writing a 1 to this bit will soft-reset the PWD, TX, RX, and CTRL registers

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Methods from Deref<Target = W<CTRL_SPEC>>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.