pub struct ENDEVPLUGINDET_W<'a> { /* private fields */ }Expand description
Field ENDEVPLUGINDET writer - Enables non-standard resistive plugged-in detection This bit field controls connection of nominal 200kohm resistors to both the USB_DP and USB_DM pins as one method of detecting when a USB cable is attached in device mode
Implementations
Sourceimpl<'a> ENDEVPLUGINDET_W<'a>
impl<'a> ENDEVPLUGINDET_W<'a>