pub struct R(/* private fields */);Expand description
Register CTRL_SET reader
Implementations
Sourceimpl R
impl R
Sourcepub fn enhostdiscondetect(&self) -> ENHOSTDISCONDETECT_R
pub fn enhostdiscondetect(&self) -> ENHOSTDISCONDETECT_R
Bit 1 - For host mode, enables high-speed disconnect detector
Sourcepub fn enirqhostdiscon(&self) -> ENIRQHOSTDISCON_R
pub fn enirqhostdiscon(&self) -> ENIRQHOSTDISCON_R
Bit 2 - Enable IRQ for Host disconnect: Enables interrupt for detection of disconnection to Device when in high-speed host mode
Sourcepub fn hostdiscondetect_irq(&self) -> HOSTDISCONDETECT_IRQ_R
pub fn hostdiscondetect_irq(&self) -> HOSTDISCONDETECT_IRQ_R
Bit 3 - Indicates that the device has disconnected in High-Speed mode
Sourcepub fn endevplugindet(&self) -> ENDEVPLUGINDET_R
pub fn endevplugindet(&self) -> ENDEVPLUGINDET_R
Bit 4 - Enables non-standard resistive plugged-in detection This bit field controls connection of nominal 200kohm resistors to both the USB_DP and USB_DM pins as one method of detecting when a USB cable is attached in device mode
Sourcepub fn devplugin_polarity(&self) -> DEVPLUGIN_POLARITY_R
pub fn devplugin_polarity(&self) -> DEVPLUGIN_POLARITY_R
Bit 5 - Device plugin polarity: For device mode, if this bit is cleared to 0, then it trips the interrupt if the device is plugged in
Sourcepub fn resumeirqsticky(&self) -> RESUMEIRQSTICKY_R
pub fn resumeirqsticky(&self) -> RESUMEIRQSTICKY_R
Bit 8 - Resume IRQ: Set to 1 will make RESUME_IRQ bit a sticky bit until software clear it
Sourcepub fn enirqresumedetect(&self) -> ENIRQRESUMEDETECT_R
pub fn enirqresumedetect(&self) -> ENIRQRESUMEDETECT_R
Bit 9 - Enable IRQ Resume detect: Enables interrupt for detection of a non-J state on the USB line
Sourcepub fn resume_irq(&self) -> RESUME_IRQ_R
pub fn resume_irq(&self) -> RESUME_IRQ_R
Bit 10 - Resume IRQ: Indicates that the host is sending a wake-up after suspend
Sourcepub fn devplugin_irq(&self) -> DEVPLUGIN_IRQ_R
pub fn devplugin_irq(&self) -> DEVPLUGIN_IRQ_R
Bit 12 - Indicates that the device is connected
Sourcepub fn enutmilevel2(&self) -> ENUTMILEVEL2_R
pub fn enutmilevel2(&self) -> ENUTMILEVEL2_R
Bit 14 - Enables UTMI+ Level 2 operation for the USB HS PHY
Sourcepub fn enutmilevel3(&self) -> ENUTMILEVEL3_R
pub fn enutmilevel3(&self) -> ENUTMILEVEL3_R
Bit 15 - Enables UTMI+ Level 3 operation for the USB HS PHY
Sourcepub fn enirqwakeup(&self) -> ENIRQWAKEUP_R
pub fn enirqwakeup(&self) -> ENIRQWAKEUP_R
Bit 16 - Enable wake-up IRQ: Enables interrupt for the wake-up events.
Sourcepub fn wakeup_irq(&self) -> WAKEUP_IRQ_R
pub fn wakeup_irq(&self) -> WAKEUP_IRQ_R
Bit 17 - Wake-up IRQ: Indicates that there is a wak-eup event
Sourcepub fn autoresume_en(&self) -> AUTORESUME_EN_R
pub fn autoresume_en(&self) -> AUTORESUME_EN_R
Bit 18 - Enable the auto resume feature, when set, HW will use 32KHz clock to send Resume to respond to the device remote wakeup(for host mode only)
Sourcepub fn enautoclr_clkgate(&self) -> ENAUTOCLR_CLKGATE_R
pub fn enautoclr_clkgate(&self) -> ENAUTOCLR_CLKGATE_R
Bit 19 - Enables the feature to auto-clear the CLKGATE bit if there is wakeup event while USB is suspended
Sourcepub fn enautoclr_phy_pwd(&self) -> ENAUTOCLR_PHY_PWD_R
pub fn enautoclr_phy_pwd(&self) -> ENAUTOCLR_PHY_PWD_R
Bit 20 - Enables the feature to auto-clear the PWD register bits in PWD if there is wakeup event while USB is suspended
Sourcepub fn endpdmchg_wkup(&self) -> ENDPDMCHG_WKUP_R
pub fn endpdmchg_wkup(&self) -> ENDPDMCHG_WKUP_R
Bit 21 - Enable DP DM change wake-up: Not for customer use
Sourcepub fn envbuschg_wkup(&self) -> ENVBUSCHG_WKUP_R
pub fn envbuschg_wkup(&self) -> ENVBUSCHG_WKUP_R
Bit 23 - Enable VBUS change wake-up: Enables the feature to wake-up USB if VBUS is toggled when USB is suspended
Sourcepub fn enautoclr_usbclkgate(&self) -> ENAUTOCLR_USBCLKGATE_R
pub fn enautoclr_usbclkgate(&self) -> ENAUTOCLR_USBCLKGATE_R
Bit 25 - Enable auto-clear USB Clock gate: Enables the feature to auto-clear the USB0_CLKGATE/USB1_CLKGATE register bit in HW_DIGCTL_CTRL if there is wake-up event on USB0/USB1 while USB0/USB1 is suspended
Sourcepub fn enautoset_usbclks(&self) -> ENAUTOSET_USBCLKS_R
pub fn enautoset_usbclks(&self) -> ENAUTOSET_USBCLKS_R
Bit 26 - Enable auto-set of USB clocks: Enables the feature to auto-clear the EN_USB_CLKS register bits in HW_CLKCTRL_PLL1CTRL0/HW_CLKCTRL_P LL1CTRL1 if there is wake-up event on USB0/USB1 while USB0/USB1 is suspended
Sourcepub fn host_force_ls_se0(&self) -> HOST_FORCE_LS_SE0_R
pub fn host_force_ls_se0(&self) -> HOST_FORCE_LS_SE0_R
Bit 28 - Forces the next FS packet that is transmitted to have a EOP with low-speed timing
Sourcepub fn utmi_suspendm(&self) -> UTMI_SUSPENDM_R
pub fn utmi_suspendm(&self) -> UTMI_SUSPENDM_R
Bit 29 - Used by the PHY to indicate a powered-down state