pub struct CSKIP_R(/* private fields */);Expand description
Field CSKIP reader - Skip rules on Carry if needed. This operation will be skipped based on Carry value (from previous operation) if not 0:
Implementations
Sourceimpl CSKIP_R
impl CSKIP_R
Sourcepub fn is_no_skip(&self) -> bool
pub fn is_no_skip(&self) -> bool
Checks if the value of the field is NO_SKIP
Sourcepub fn is_skip_if_1(&self) -> bool
pub fn is_skip_if_1(&self) -> bool
Checks if the value of the field is SKIP_IF_1
Sourcepub fn is_skip_if_0(&self) -> bool
pub fn is_skip_if_0(&self) -> bool
Checks if the value of the field is SKIP_IF_0
Sourcepub fn is_set_and_skip(&self) -> bool
pub fn is_set_and_skip(&self) -> bool
Checks if the value of the field is SET_AND_SKIP
Methods from Deref<Target = FieldReader<u8, CSKIP_A>>