pub struct SWRESET_W<'a> { /* private fields */ }Expand description
Field SWRESET writer - Software reset control
Implementations
Sourceimpl<'a> SWRESET_W<'a>
impl<'a> SWRESET_W<'a>
Sourcepub fn not_in_reset(self) -> &'a mut W
pub fn not_in_reset(self) -> &'a mut W
Not in reset. The RTC is not held in reset. This bit must be cleared prior to configuring or initiating any operation of the RTC.
Sourcepub fn in_reset(self) -> &'a mut W
pub fn in_reset(self) -> &'a mut W
In reset. The RTC is held in reset. All register bits within the RTC will be forced to their reset value except the OFD bit. This bit must be cleared before writing to any register in the RTC - including writes to set any of the other bits within this register. Do not attempt to write to any bits of this register at the same time that the reset bit is being cleared.