Selects sources and data combinations for shared signal set index.
Structs
- FC0DATAOUTEN_
R - Field
FC0DATAOUTENreader - Controls FC0 contribution to SHAREDDATAOUT for this shared set. - FC0DATAOUTEN_
W - Field
FC0DATAOUTENwriter - Controls FC0 contribution to SHAREDDATAOUT for this shared set. - FC1DATAOUTEN_
R - Field
FC1DATAOUTENreader - Controls FC1 contribution to SHAREDDATAOUT for this shared set. - FC1DATAOUTEN_
W - Field
FC1DATAOUTENwriter - Controls FC1 contribution to SHAREDDATAOUT for this shared set. - FC2DATAOUTEN_
R - Field
FC2DATAOUTENreader - Controls FC2 contribution to SHAREDDATAOUT for this shared set. - FC2DATAOUTEN_
W - Field
FC2DATAOUTENwriter - Controls FC2 contribution to SHAREDDATAOUT for this shared set. - FC4DATAOUTEN_
R - Field
FC4DATAOUTENreader - Controls FC4 contribution to SHAREDDATAOUT for this shared set. - FC4DATAOUTEN_
W - Field
FC4DATAOUTENwriter - Controls FC4 contribution to SHAREDDATAOUT for this shared set. - FC5DATAOUTEN_
R - Field
FC5DATAOUTENreader - Controls FC5 contribution to SHAREDDATAOUT for this shared set. - FC5DATAOUTEN_
W - Field
FC5DATAOUTENwriter - Controls FC5 contribution to SHAREDDATAOUT for this shared set. - FC6DATAOUTEN_
R - Field
FC6DATAOUTENreader - Controls FC6 contribution to SHAREDDATAOUT for this shared set. - FC6DATAOUTEN_
W - Field
FC6DATAOUTENwriter - Controls FC6 contribution to SHAREDDATAOUT for this shared set. - FC7DATAOUTEN_
R - Field
FC7DATAOUTENreader - Controls FC7 contribution to SHAREDDATAOUT for this shared set. - FC7DATAOUTEN_
W - Field
FC7DATAOUTENwriter - Controls FC7 contribution to SHAREDDATAOUT for this shared set. - R
- Register
SHAREDCTRLSET%sreader - SHAREDCTRLSET_
SPEC - Selects sources and data combinations for shared signal set index.
- SHAREDDATASEL_
R - Field
SHAREDDATASELreader - Selects the source for DATA input for this shared signal set. - SHAREDDATASEL_
W - Field
SHAREDDATASELwriter - Selects the source for DATA input for this shared signal set. - SHAREDSCKSEL_
R - Field
SHAREDSCKSELreader - Selects the source for SCK of this shared signal set. - SHAREDSCKSEL_
W - Field
SHAREDSCKSELwriter - Selects the source for SCK of this shared signal set. - SHAREDWSSEL_
R - Field
SHAREDWSSELreader - Selects the source for WS of this shared signal set. - SHAREDWSSEL_
W - Field
SHAREDWSSELwriter - Selects the source for WS of this shared signal set. - W
- Register
SHAREDCTRLSET%swriter
Enums
- FC0DATAOUTEN_
A - Controls FC0 contribution to SHAREDDATAOUT for this shared set.
- FC1DATAOUTEN_
A - Controls FC1 contribution to SHAREDDATAOUT for this shared set.
- FC2DATAOUTEN_
A - Controls FC2 contribution to SHAREDDATAOUT for this shared set.
- FC4DATAOUTEN_
A - Controls FC4 contribution to SHAREDDATAOUT for this shared set.
- FC5DATAOUTEN_
A - Controls FC5 contribution to SHAREDDATAOUT for this shared set.
- FC6DATAOUTEN_
A - Controls FC6 contribution to SHAREDDATAOUT for this shared set.
- FC7DATAOUTEN_
A - Controls FC7 contribution to SHAREDDATAOUT for this shared set.
- SHAREDDATASEL_
A - Selects the source for DATA input for this shared signal set.
- SHAREDSCKSEL_
A - Selects the source for SCK of this shared signal set.
- SHAREDWSSEL_
A - Selects the source for WS of this shared signal set.