pub struct R(/* private fields */);Expand description
Register DEVCMDSTAT reader
Implementations
Sourceimpl R
impl R
Sourcepub fn dev_addr(&self) -> DEV_ADDR_R
pub fn dev_addr(&self) -> DEV_ADDR_R
Bits 0:6 - USB device address.
Sourcepub fn force_needclk(&self) -> FORCE_NEEDCLK_R
pub fn force_needclk(&self) -> FORCE_NEEDCLK_R
Bit 9 - Forces the NEEDCLK output to always be on:.
Sourcepub fn intonnak_ao(&self) -> INTONNAK_AO_R
pub fn intonnak_ao(&self) -> INTONNAK_AO_R
Bit 12 - Interrupt on NAK for interrupt and bulk OUT EP:.
Sourcepub fn intonnak_ai(&self) -> INTONNAK_AI_R
pub fn intonnak_ai(&self) -> INTONNAK_AI_R
Bit 13 - Interrupt on NAK for interrupt and bulk IN EP:.
Sourcepub fn intonnak_co(&self) -> INTONNAK_CO_R
pub fn intonnak_co(&self) -> INTONNAK_CO_R
Bit 14 - Interrupt on NAK for control OUT EP:.
Sourcepub fn intonnak_ci(&self) -> INTONNAK_CI_R
pub fn intonnak_ci(&self) -> INTONNAK_CI_R
Bit 15 - Interrupt on NAK for control IN EP:.
Sourcepub fn lpm_rewp(&self) -> LPM_REWP_R
pub fn lpm_rewp(&self) -> LPM_REWP_R
Bit 20 - LPM Remote Wake-up Enabled by USB host.
Sourcepub fn speed(&self) -> SPEED_R
pub fn speed(&self) -> SPEED_R
Bits 22:23 - This field indicates the speed at which the device operates: 00b: reserved 01b: full-speed 10b: high-speed 11b: super-speed (reserved for future use).
Sourcepub fn vbus_debounced(&self) -> VBUS_DEBOUNCED_R
pub fn vbus_debounced(&self) -> VBUS_DEBOUNCED_R
Bit 28 - This bit indicates if VBUS is detected or not.
Sourcepub fn phy_test_mode(&self) -> PHY_TEST_MODE_R
pub fn phy_test_mode(&self) -> PHY_TEST_MODE_R
Bits 29:31 - This field is written by firmware to put the PHY into a test mode as defined by the USB2.0 specification
Sourcepub fn force_fs(&self) -> FORCE_FS_R
pub fn force_fs(&self) -> FORCE_FS_R
Bit 21 - Force USB device to operate in full-speed mode.