pub struct W(/* private fields */);Expand description
Register DEVCMDSTAT writer
Implementations
Sourceimpl W
impl W
Sourcepub fn dev_addr(&mut self) -> DEV_ADDR_W<'_>
pub fn dev_addr(&mut self) -> DEV_ADDR_W<'_>
Bits 0:6 - USB device address.
Sourcepub fn force_needclk(&mut self) -> FORCE_NEEDCLK_W<'_>
pub fn force_needclk(&mut self) -> FORCE_NEEDCLK_W<'_>
Bit 9 - Forces the NEEDCLK output to always be on:.
Sourcepub fn intonnak_ao(&mut self) -> INTONNAK_AO_W<'_>
pub fn intonnak_ao(&mut self) -> INTONNAK_AO_W<'_>
Bit 12 - Interrupt on NAK for interrupt and bulk OUT EP:.
Sourcepub fn intonnak_ai(&mut self) -> INTONNAK_AI_W<'_>
pub fn intonnak_ai(&mut self) -> INTONNAK_AI_W<'_>
Bit 13 - Interrupt on NAK for interrupt and bulk IN EP:.
Sourcepub fn intonnak_co(&mut self) -> INTONNAK_CO_W<'_>
pub fn intonnak_co(&mut self) -> INTONNAK_CO_W<'_>
Bit 14 - Interrupt on NAK for control OUT EP:.
Sourcepub fn intonnak_ci(&mut self) -> INTONNAK_CI_W<'_>
pub fn intonnak_ci(&mut self) -> INTONNAK_CI_W<'_>
Bit 15 - Interrupt on NAK for control IN EP:.
Sourcepub fn phy_test_mode(&mut self) -> PHY_TEST_MODE_W<'_>
pub fn phy_test_mode(&mut self) -> PHY_TEST_MODE_W<'_>
Bits 29:31 - This field is written by firmware to put the PHY into a test mode as defined by the USB2.0 specification
Sourcepub fn force_fs(&mut self) -> FORCE_FS_W<'_>
pub fn force_fs(&mut self) -> FORCE_FS_W<'_>
Bit 21 - Force USB device to operate in full-speed mode.
Methods from Deref<Target = W<DEVCMDSTAT_SPEC>>